@@ -3,13 +3,22 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*    Copyright (C) 2002-2022 Konrad-Zuse-Zentrum                            */
-/*                            fuer Informationstechnik Berlin                */
+/*  Copyright 2002-2022 Zuse Institute Berlin                                */
 /*                                                                           */
-/*  SCIP is distributed under the terms of the ZIB Academic License.         */
+/*  Licensed under the Apache License, Version 2.0 (the "License");          */
+/*  you may not use this file except in compliance with the License.         */
+/*  You may obtain a copy of the License at                                  */
 /*                                                                           */
-/*  You should have received a copy of the ZIB Academic License              */
-/*  along with SCIP; see the file COPYING. If not visit scipopt.org.         */
+/*      http://www.apache.org/licenses/LICENSE-2.0                           */
+/*                                                                           */
+/*  Unless required by applicable law or agreed to in writing, software      */
+/*  distributed under the License is distributed on an "AS IS" BASIS,        */
+/*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. */
+/*  See the License for the specific language governing permissions and      */
+/*  limitations under the License.                                           */
+/*                                                                           */
+/*  You should have received a copy of the Apache-2.0 license                */
+/*  along with SCIP; see the file LICENSE. If not visit scipopt.org.         */
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
@@ -520,6 +529,7 @@ SCIP_Real getRelDistance(
    )
 {
    SCIP_VAR** vars;
+   int nvars;
    SCIP_Real distance;
    SCIP_Real solx;
    SCIP_Real soly;
@@ -531,12 +541,13 @@ SCIP_Real getRelDistance(
    assert(y != NULL);
 
    vars = SCIPgetVars(scip);
+   nvars = SCIPgetNVars(scip);
    distance = 0.0;
 
-   if( SCIPgetNVars(scip) == 0 )
+   if( nvars == 0 )
       return 0.0;
 
-   for( i = 0; i < SCIPgetNVars(scip); ++i )
+   for( i = 0; i < nvars; ++i )
    {
       lb = SCIPvarGetLbLocal(vars[i]);
       ub = SCIPvarGetUbLocal(vars[i]);
@@ -565,7 +576,7 @@ SCIP_Real getRelDistance(
       distance += REALABS(solx - soly) / MAX(1.0, ub - lb);
    }
 
-   return distance / SCIPgetNVars(scip);
+   return distance / nvars;
 }
 
 /** cluster useful points with a greedy algorithm */
